//
//  IngredientsViewController.m
//  Recipes
//
//  Created by bill on 6/6/08.
//  Copyright 2008 __MyCompanyName__. All rights reserved.
//

#import "IngredientsViewController.h"
#import "RecipesAppDelegate.h"
#import "RecipesViewController.h"


@implementation IngredientsViewController

@synthesize ingredients;
@synthesize recipesController;

- (void)setEditing:(BOOL)editing animated:(BOOL)animated {
	if(self.editing != editing) {
		[super setEditing:editing animated:animated];
		[tableView setEditing:editing animated:animated];
		NSArray *indexPaths = [NSArray arrayWithObject:
							   [NSIndexPath indexPathForRow:
								self.ingredients.count inSection:0]];
		if(YES == editing) {
			[tableView insertRowsAtIndexPaths:indexPaths 
							 withRowAnimation:UITableViewRowAnimationLeft];
		} else {
			[tableView deleteRowsAtIndexPaths:indexPaths 
							 withRowAnimation:UITableViewRowAnimationLeft];
		}
	}
}

- (void)tableView:(UITableView *)tv didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
	if(indexPath.row >= ingredients.count) {
		[recipesController displayAddNewIngredientScreen:self.title];
	} else {
		// As an exercies place the selected ingredient into the 
		// new ingredient view controller and allow the user
		// to edit the ingredient
	}
}

- (UITableViewCellEditingStyle)tableView:(UITableView *)tableView 
           editingStyleForRowAtIndexPath:(NSIndexPath *)indexPath {
    if (indexPath.row < [self.ingredients count]) {
        return UITableViewCellEditingStyleDelete;
    } else {
		return UITableViewCellEditingStyleInsert;
	}
    return UITableViewCellEditingStyleNone;
}

- (void)removeIngredient:(NSString *)ingredientName {
	[recipesController removeIngredient:ingredientName forRecipe:self.title];
}

- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)sourceIndexPath toIndexPath:(NSIndexPath *)destinationIndexPath {
	[recipesController moveIngredientForRecipe:self.title atIndex:sourceIndexPath.row toIndex:destinationIndexPath.row];
}

- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath {
	BOOL flag = NO;
	if(indexPath.row < ingredients.count) {
		flag = YES;
	}
	return flag;
}

- (NSIndexPath *)tableView:(UITableView *)tableView targetIndexPathForMoveFromRowAtIndexPath:(NSIndexPath *)sourceIndexPath toProposedIndexPath:(NSIndexPath *)proposedDestinationIndexPath {
	NSIndexPath *indexPath = proposedDestinationIndexPath;
	if(proposedDestinationIndexPath.row >= ingredients.count) {
		indexPath = [NSIndexPath indexPathForRow:ingredients.count - 1 inSection:0];
	}
	return indexPath;
}

- (void)tableView:(UITableView *)tv commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
	if(editingStyle == UITableViewCellEditingStyleDelete && indexPath.row < [self.ingredients count]) {
		[self removeIngredient:[[tv cellForRowAtIndexPath:indexPath] text]];
		[tv deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationLeft];
	}
}

- (UITableViewCell *)tableView:(UITableView *)tv cellForRowAtIndexPath:(NSIndexPath *)indexPath {
	UITableViewCell *cell = [tv dequeueReusableCellWithIdentifier:@"ingredientsCell"];
	if(nil == cell) {
		cell = [[UITableViewCell alloc] initWithFrame:CGRectZero reuseIdentifier:nil];
	}
	if(indexPath.row < self.ingredients.count) {
		cell.text = [self.ingredients objectAtIndex:indexPath.row];
	} else {
		cell.text = @"Add new ingredient";
		cell.textColor = [UIColor lightGrayColor];
		cell.hidesAccessoryWhenEditing = NO;
		cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
	}
	return cell;
}

- (NSInteger)tableView:(UITableView *)tv numberOfRowsInSection:(NSInteger)section {
	NSInteger count = self.ingredients.count;
	if(self.editing) {
		count++;
	}
	return count;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
	// Return YES for supported orientations
	return (interfaceOrientation == UIInterfaceOrientationPortrait);
}


- (void)didReceiveMemoryWarning {
	[super didReceiveMemoryWarning]; // Releases the view if it doesn't have a superview
	// Release anything that's not essential, such as cached data
}

- (void)viewDidLoad {
	self.navigationItem.rightBarButtonItem = self.editButtonItem;
}

- (void)viewWillAppear:(BOOL)animated {
	[tableView reloadData];
}

- (void)viewWillDisappear:(BOOL)animated {
	[self setEditing:NO animated:YES];
}

- (void)dealloc {
	self.recipesController = nil;
	self.ingredients = nil;
	[super dealloc];
}

@end
